Learn R Programming

CropWaterBalance (version 0.2.0)

ET0_PT: Reference Evapotranspiration Using the Preistley-Taylor Method

Description

Calculates daily reference evapotranspiration amounts using the Priestley-Taylor method.

Usage

ET0_PT(Tavg, Rn, G = NULL, Coeff = 1.26)

Value

A matrix object of the daily potential evapotranspiration values in millimetres.

Arguments

Tavg

A vector, 1-column matrix or data frame with daily average air temperature.

Rn

A vector, 1-column matrix or data frame with daily net radiation in \(MJ m-2 day-1\).

G

Optional. A vector, 1-column matrix or data frame with daily soil heat flux in \(MJ m-2 day-1\). May be provided by Soil_Heat_Flux

Coeff

Single number defining the Priestley and Taylor coefficient. Default is 1.26.

Examples

Run this code
# See `?DataForCWB` for more on this data set
Tavg <- DataForCWB[, 2]
Rn <- DataForCWB[, 6]
G <- DataForCWB[, 9]
ET0_PT(Tavg = Tavg, Rn = Rn, G = G)

Run the code above in your browser using DataLab